@@ -26,27 +26,25 @@
 int
 main(int argc, char *argv[])
 {
-	char *uri = argv[1];
-	GsfDocMetaData *meta_data;
-	GsfDocProp *prop;
-	const GValue *value;
-	const char *tmp;
+    char *uri = argv[1];
+    GsfDocMetaData *meta_data;
+    GsfDocProp *prop;
+    const GValue *value;
+    const char *tmp;
 
-	gsf_init();
+    gsf_init();
 
-	meta_data = props_data_read(uri, NULL);
+    meta_data = props_data_read(uri, NULL);
+    if (meta_data) {
+        prop = gsf_doc_meta_data_lookup(meta_data, GSF_META_NAME_TITLE);
+        if (prop) {
+            value = gsf_doc_prop_get_val(prop);
 
-	prop = gsf_doc_meta_data_lookup(meta_data, GSF_META_NAME_TITLE);
-	if (prop) {
-		value = gsf_doc_prop_get_val(prop);
+            tmp = g_value_get_string(value);
+            fprintf(stderr, "str: %s\n", tmp);
+        }
+        g_object_unref(meta_data);
+    }
 
-		tmp = g_value_get_string(value);
-		fprintf(stderr, "str: %s\n", tmp);
-	}
-
-	g_object_unref(meta_data);
-
-	gsf_shutdown();
-
-	exit(0);
+    exit(0);
 }
